/// <reference types="node" />
import { ClippingMask, Document, Ellipse, ILAAsset, ILAData, Layer, Polygon, TextLayer } from "../../internal";
import { AlignOptions } from "./align";
import { ExportTypes, Format, Output, PathOrWithMetadataOptions } from "./exportTo";
export declare type AnyLayer = BaseLayer | Layer | TextLayer | Polygon | Ellipse | ClippingMask;
export declare type LayerType = typeof LAYER_TYPE_LAYER | typeof LAYER_TYPE_TEXT | typeof LAYER_TYPE_POLYGON | typeof LAYER_TYPE_ELLIPSE | typeof LAYER_TYPE_CLIPPING_MASK;
export declare const LAYER_TYPE_LAYER = 0;
export declare const LAYER_TYPE_TEXT = 1;
export declare const LAYER_TYPE_POLYGON = 2;
export declare const LAYER_TYPE_ELLIPSE = 3;
export declare const LAYER_TYPE_CLIPPING_MASK = 4;
export interface Rotate {
    type: "rotate";
    degrees: number;
}
export interface Resize {
    type: "resize";
    width?: number;
    height?: number;
}
export interface Reflect {
    type: "reflect";
    direction: ReflectDirection;
}
export interface Hue {
    type: "hue";
    degrees: number;
}
export interface Saturation {
    type: "saturation";
    amount: number;
}
export interface Brightness {
    type: "brightness";
    amount: number;
}
export interface Invert {
    type: "invert";
}
export interface Blur {
    type: "blur";
    sigma: number;
}
export declare type Edit = Rotate | Resize | Reflect | Hue | Saturation | Brightness | Invert | Blur;
export declare type ReflectDirection = "vertical" | "horizontal";
export declare type BlendMode = "normal" | "darken" | "multiply" | "colorBurn" | "lighten" | "screen" | "colorDodge" | "linearDodge" | "overlay" | "softLight" | "hardLight" | "difference" | "exclusion";
export declare const BLEND_MODES: BlendMode[];
export interface BaseLayerData {
    name: string;
    left?: number;
    top?: number;
    position?: number;
    debugMode?: boolean;
}
export default class BaseLayer {
    document?: Document;
    name: string;
    type: LayerType;
    left: number;
    top: number;
    get position(): number;
    _edits: Edit[];
    opacity: number;
    blendMode: BlendMode;
    debugMode: boolean;
    constructor(baseLayerData: BaseLayerData, document?: Document);
    setName(name: string): void;
    duplicate(name?: string, position?: number, debugMode?: boolean): Promise<this>;
    move(position: number, relative?: boolean): number;
    translate(left?: number, top?: number): this;
    translateBy(x?: number, y?: number): this;
    align(alignOptions?: AlignOptions): this;
    rotate(degrees: number): this;
    resize(width?: number | null, height?: number | null): this;
    resizeBy(width?: number | null, height?: number | null, scale?: boolean): this;
    reflect(direction: ReflectDirection): this;
    setOpacity(opacity: number): this;
    setBlendMode(blendMode?: BlendMode | null): this;
    hue(degrees: number): this;
    saturation(amount: number): this;
    brightness(amount: number): this;
    grayscale(): this;
    invert(): this;
    blur(sigma: number): this;
    circularMask(name: string, keepSource?: boolean): ClippingMask;
    remove(): void;
    rasterize(): Promise<Layer>;
    exportTo<ExportType extends ExportTypes, PathOrWithMetadata extends PathOrWithMetadataOptions = false>(format: Format, exportType: ExportType, pathOrWithMetadata?: PathOrWithMetadata): Promise<Output<ExportType, PathOrWithMetadata>>;
    exportILA<ExportType extends ExportTypes, Path extends string>(exportType: ExportType, path?: Path): Promise<Output<ExportType, Path>>;
    static importILA(pathOrBuffer: string | Buffer, assetsDirectory?: string): Promise<AnyLayer>;
    _getILAData(assets: ILAAsset[]): ILAData;
    setDebugMode(debugMode: boolean): void;
    _debug(info: string): void;
}
