"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_1 = require("../../../internal");
async function parseILAData(ilaData, assets) {
    let createdLayer;
    if (typeof ilaData.name !== "string")
        throw new Error("Error parsing Illustra file");
    if (![internal_1.LAYER_TYPE_LAYER, internal_1.LAYER_TYPE_TEXT, internal_1.LAYER_TYPE_POLYGON, internal_1.LAYER_TYPE_ELLIPSE, internal_1.LAYER_TYPE_CLIPPING_MASK].includes(ilaData.type))
        throw new Error("Error parsing Illustra file");
    if (typeof ilaData.left !== "number")
        throw new Error("Error parsing Illustra file");
    if (typeof ilaData.top !== "number")
        throw new Error("Error parsing Illustra file");
    if (!(ilaData.edits instanceof Array))
        throw new Error("Error parsing Illustra file");
    if ((typeof ilaData.opacity !== "number") || (ilaData.opacity < 0) || (ilaData.opacity > 100))
        throw new Error("Error parsing Illustra file");
    if (!internal_1.BLEND_MODES.includes(ilaData.blendMode))
        throw new Error("Error parsing Illustra file");
    if (ilaData.type === internal_1.LAYER_TYPE_TEXT) {
        if (typeof ilaData.text !== "string")
            throw new Error("Error parsing Illustra file");
        if ((ilaData.font !== undefined) && (typeof ilaData.font !== "string"))
            throw new Error("Error parsing Illustra file");
        if (typeof ilaData.fontSize !== "number")
            throw new Error("Error parsing Illustra file");
        if ((ilaData.fontWeight !== undefined) && (typeof ilaData.fontWeight !== "string"))
            throw new Error("Error parsing Illustra file");
        if (typeof ilaData.color !== "string")
            throw new Error("Error parsing Illustra file");
        if (typeof ilaData.maxWidth !== "number")
            throw new Error("Error parsing Illustra file");
        createdLayer = internal_1.createTextLayer({
            name: ilaData.name,
            text: {
                text: ilaData.text,
                font: ilaData.font,
                fontSize: ilaData.fontSize,
                fontWeight: ilaData.fontWeight,
                color: ilaData.color,
                maxWidth: ilaData.maxWidth
            },
            left: ilaData.left,
            top: ilaData.top
        });
    }
    else if (ilaData.type === internal_1.LAYER_TYPE_POLYGON) {
        if (typeof ilaData.width !== "number")
            throw new Error("Error parsing Illustra file");
        if (typeof ilaData.height !== "number")
            throw new Error("Error parsing Illustra file");
        if ((ilaData.fill !== undefined) && (typeof ilaData.fill !== "string"))
            throw new Error("Error parsing Illustra file");
        if ((ilaData.stroke !== undefined) && (typeof ilaData.stroke !== "string"))
            throw new Error("Error parsing Illustra file");
        if ((ilaData.strokeWidth !== undefined) && (typeof ilaData.strokeWidth !== "number"))
            throw new Error("Error parsing Illustra file");
        if (typeof ilaData.sides !== "number")
            throw new Error("Error parsing Illustra file");
        createdLayer = internal_1.createPolygon({
            name: ilaData.name,
            shape: {
                width: ilaData.width,
                height: ilaData.height,
                fill: ilaData.fill,
                stroke: ilaData.stroke,
                strokeWidth: ilaData.strokeWidth,
                sides: ilaData.sides
            },
            left: ilaData.left,
            top: ilaData.top
        });
    }
    else if (ilaData.type === internal_1.LAYER_TYPE_ELLIPSE) {
        if (typeof ilaData.width !== "number")
            throw new Error("Error parsing Illustra file");
        if (typeof ilaData.height !== "number")
            throw new Error("Error parsing Illustra file");
        if ((ilaData.fill !== undefined) && (typeof ilaData.fill !== "string"))
            throw new Error("Error parsing Illustra file");
        if ((ilaData.stroke !== undefined) && (typeof ilaData.stroke !== "string"))
            throw new Error("Error parsing Illustra file");
        if ((ilaData.strokeWidth !== undefined) && (typeof ilaData.strokeWidth !== "number"))
            throw new Error("Error parsing Illustra file");
        createdLayer = internal_1.createEllipse({
            name: ilaData.name,
            shape: {
                width: ilaData.width,
                height: ilaData.height,
                fill: ilaData.fill,
                stroke: ilaData.stroke,
                strokeWidth: ilaData.strokeWidth
            },
            left: ilaData.left,
            top: ilaData.top
        });
    }
    else if (ilaData.type === internal_1.LAYER_TYPE_CLIPPING_MASK) {
        if (typeof ilaData.mask !== "object")
            throw new Error("Error parsing Illustra file");
        if (typeof ilaData.source !== "object")
            throw new Error("Error parsing Illustra file");
        createdLayer = internal_1.createClippingMask({
            name: ilaData.name,
            mask: await parseILAData(ilaData.mask, assets),
            source: await parseILAData(ilaData.source, assets),
            left: ilaData.left,
            top: ilaData.top
        });
    }
    else
        createdLayer = await internal_1.createLayer({
            name: ilaData.name,
            image: assets[ilaData.inputImageID - 1],
            left: ilaData.left,
            top: ilaData.top
        });
    ilaData.edits.forEach((e) => {
        if (e.type === "rotate") {
            if (typeof e.degrees !== "number")
                throw new Error("Error parsing Illustra file");
            createdLayer.rotate(e.degrees);
        }
        else if (e.type === "resize") {
            if ((e.width !== undefined) && (typeof e.width !== "number"))
                throw new Error("Error parsing Illustra file");
            if ((e.height !== undefined) && (typeof e.height !== "number"))
                throw new Error("Error parsing Illustra file");
            createdLayer.resize(e.width, e.height);
        }
        else if (e.type === "reflect") {
            if (!["vertical", "horizontal"].includes(e.direction))
                throw new Error("Error parsing Illustra file");
            createdLayer.reflect(e.direction);
        }
        else if (e.type === "hue") {
            if (typeof e.degrees !== "number")
                throw new Error("Error parsing Illustra file");
            createdLayer.hue(e.degrees);
        }
        else if (e.type === "saturation") {
            if (typeof e.amount !== "number")
                throw new Error("Error parsing Illustra file");
            createdLayer.saturation(e.amount);
        }
        else if (e.type === "brightness") {
            if (typeof e.amount !== "number")
                throw new Error("Error parsing Illustra file");
            createdLayer.brightness(e.amount);
        }
        else if (e.type === "invert")
            createdLayer.invert();
        else if (e.type === "blur") {
            if (typeof e.sigma !== "number")
                throw new Error("Error parsing Illustra file");
            createdLayer.blur(e.sigma);
        }
        else
            throw new Error("Error parsing Illustra file");
    });
    createdLayer.setOpacity(ilaData.opacity);
    createdLayer.setBlendMode(ilaData.blendMode);
    return createdLayer;
}
exports.default = parseILAData;
